@@ -39,7 +39,6 @@ from .common import (
     get_versions_dir,
     get_version_dir,
     get_volare_dir,
-    get_date_of,
     connected_to_internet,
 )
 from .build import build, push
@@ -104,11 +103,13 @@ def print_remote_list(
     for remote_version in pdk_list:
         name = remote_version.name
         day = remote_version.commit_date.strftime("%Y.%m.%d")
-        desc = f"{name} ({day})"
+        desc = f"[green]{name} ({day})"
+        if remote_version.prerelease:
+            desc = f"[red]PRE-RELEASE {desc}"
         if name == version:
-            tree.add(f"[green][bold]{desc} (enabled)")
+            tree.add(f"[bold]{desc} (enabled)")
         elif name in installed_list:
-            tree.add(f"[green]{desc} (installed)")
+            tree.add(f"{desc} (installed)")
         else:
             tree.add(desc)
     console.print(tree)
@@ -133,8 +134,6 @@ def output_cmd(pdk_root, pdk):
     exit code of 1.
     """
 
-    print(get_date_of("44a43c23c81b45b8e774ae7a84899a5a778b6b0b"))
-
     version = get_current_version(pdk_root, pdk)
     if sys.stdout.isatty():
         if version == "":
@@ -295,7 +294,7 @@ def enable(
         with open(current_file, "w") as f:
             f.write(version)
 
-    console.print(f"PDK version {version} enabled.")
+    console.print(f"Version {version} enabled for the {pdk} PDK.")
 
 
 @click.command("enable")
@@ -345,6 +344,7 @@ def enable_or_build_cmd(
     owner,
     repository,
     token,
+    pre,
     clear_build_artifacts,
     tool_metadata_file_path,
     also_push,
@@ -372,5 +372,10 @@ def enable_or_build_cmd(
             "clear_build_artifacts": clear_build_artifacts,
             "use_repo_at": use_repo_at,
         },
-        push_kwargs={"owner": owner, "repository": repository, "token": token},
+        push_kwargs={
+            "owner": owner,
+            "repository": repository,
+            "token": token,
+            "pre": pre,
+        },
     )
